View Source mix vite.install (vite v0.3.0)

Installs Vite.

$ mix vite.install $ mix vite.install --using bun

By default, it installs 7.3.1 but you can configure it in your config files, such as:

config :vite, :version, "7.3.1"

Options

* `--using` - change the package management

* `--no-config` - does not install vite config

* `--if-missing` - install only if the given version
  does not exist

## Assets

Whenever Vite is installed, a default vite configuration will be placed in a new assets/vite.config.js file. See the vite documentation on configuration options.

Summary

Functions